@@ -25,7 +25,7 @@ locale.textdomain('kuwo')
 _ = gettext.gettext
 
 APPNAME = _('KW Player')
-VERSION = '3.1.5'
+VERSION = '3.1.6'
 HOMEPAGE = 'https://github.com/LiuLang/kwplayer'
 AUTHORS = ['LiuLang <gsushzhsosgsu@gmail.com>',]
 DESCRIPTION = _('A simple music player on Linux desktop.')
@@ -56,6 +56,17 @@ class ShortcutMode:
 
 CONF_DIR = os.path.join(HOME_DIR, '.config', 'kuwo')
 _conf_file = os.path.join(CONF_DIR, 'conf.json')
+SHORT_CUT_I18N = {
+        'VolumeUp': _('VolumeUp'),
+        'VolumeDown': _('VolumeDown'),
+        'Mute': _('Mute'),
+        'Previous': _('Previous'),
+        'Next': _('Next'),
+        'Pause': _('Pause'),
+        'Play': _('Play'),
+        'Stop': _('Stop'),
+        'Launch': _('Launch'),
+        }
 _default_conf = {
         'window-size': (960, 680),
         'song-dir': os.path.join(CACHE_DIR, 'song'),
@@ -79,6 +90,7 @@ _default_conf = {
             'Pause': '<Ctrl><Shift>Down',
             'Play': '<Ctrl><Shift>Down',
             'Stop': '<Ctrl><Shift>Up',
+            'Launch': '<Ctrl><Shift>L',
             },
         'default-shortcut': {
             'VolumeUp': 'XF86AudioRaiseVolume',
@@ -89,6 +101,7 @@ _default_conf = {
             'Pause': 'XF86AudioPause',
             'Play': 'XF86AudioPlay',
             'Stop': 'XF86AudioStop',
+            'Launch': 'XF86AudioMedia',
             },
         }
 
@@ -120,6 +133,11 @@ def load_conf():
         for key in _default_conf:
             if key not in conf:
                 conf[key] = _default_conf[key]
+        # 3.1.5 -> 3.1.6
+        if 'Launch' not in conf['custom-shortcut']:
+            conf['custom-shortcut']['Launch'] = _default_conf['custom-shortcut']['Launch']
+        if 'Launch' not in conf['default-shortcut']:
+            conf['default-shortcut']['Launch'] = _default_conf['default-shortcut']['Launch']
         return conf
     dump_conf(_default_conf)
     return _default_conf
@@ -138,11 +156,13 @@ def load_theme():
         return None
 
     theme_pix = {}
+    theme_path = {}
     for key in theme:
         filename = os.path.join(THEME_DIR, theme[key])
         if os.path.exists(filename):
             theme_pix[key] = GdkPixbuf.Pixbuf.new_from_file(filename)
+            theme_path[key] = filename
         else:
             print('Failed to open theme icon', filename)
             return None
-    return theme_pix
+    return (theme_pix, theme_path)
